@@ -306,8 +306,6 @@ int gl_get_count(GLenum param)
 	}
 #endif
 
-
-
 /* 18 */
 #ifdef GL_EXT_cmyka
 	switch (param) {
@@ -350,6 +348,27 @@ int gl_get_count(GLenum param)
 	}
 #endif
 
+#ifdef GL_EXT_framebuffer_object
+	switch (param) {
+	case GL_FRAMEBUFFER_BINDING_EXT:
+        case GL_RENDERBUFFER_BINDING_EXT:
+        case GL_MAX_COLOR_ATTACHMENTS_EXT:
+        case GL_MAX_RENDERBUFFER_SIZE_EXT:
+		return 1;
+	}
+#endif
+
+#ifdef GL_ARB_point_parameters
+	switch (param) {
+	case GL_POINT_SIZE_MIN_ARB:
+	case GL_POINT_SIZE_MAX_ARB:
+	case GL_POINT_FADE_THRESHOLD_SIZE_ARB:
+		return 1;
+	case GL_POINT_DISTANCE_ATTENUATION_ARB:
+		return 3;
+	}
+#endif
+
 /* 79 */
 #if defined(GL_EXT_clip_volume_hint) && defined(GL_VOLUME_CLIPPING_HINT_EXT)
 	switch (param) {
@@ -639,28 +658,38 @@ unsigned long gl_pixelbuffer_size(
 GLvoid * EL(SV * sv, int needlen)
 {
 	STRLEN skip = 0;
+    SV * svref;
 	
 	if (SvREADONLY(sv))
 		croak("Readonly value for buffer");
-	if(SvROK(sv))
-		sv_unref(sv);
+
+	if(SvROK(sv)) {
+        svref = SvRV(sv);
+        sv = svref;
+    }
+    else
+    {
 #ifdef USE_STRICT_UNGLOB
-	else if (SvFAKE(sv) && SvTYPE(sv) == SVt_PVGV)
-		sv_unglob(sv);
+        if (SvFAKE(sv) && SvTYPE(sv) == SVt_PVGV)
+            sv_unglob(sv);
 #endif
 
-	SvUPGRADE(sv, SVt_PV);
-	SvGROW(sv, (unsigned int)(needlen + 1));
-	SvPOK_on(sv);
-	SvCUR_set(sv, needlen);
-	*SvEND(sv) = '\0';
+        SvUPGRADE(sv, SVt_PV);
+        SvGROW(sv, (unsigned int)(needlen + 1));
+        SvPOK_on(sv);
+        SvCUR_set(sv, needlen);
+        *SvEND(sv) = '\0';  /* Why is this here? -chm */
+    }
+
 	return SvPV_force(sv, skip);
 }
 
 GLvoid * ELI(SV * sv, GLsizei width, GLsizei height, 
              GLenum format, GLenum type, int mode)
 {
-	int needlen = gl_pixelbuffer_size(format, width, height, type, mode);
+	int needlen = 0;
+    if (!SvROK(sv)) /* don't calc length if arg is a perl ref */
+        needlen = gl_pixelbuffer_size(format, width, height, type, mode);
 	return EL(sv, needlen);
 }
 
